==> sammaadmin-1.00.tar.gz: htdocs/admin/postldapadmin/samma/tmpl/help.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * إײ
 *
 * $RCSfile: help.php,v $
 * $Revision: 1.2 $
 * $Date: 2010/06/24 08:59:25 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION",  "إײ");

/***********************************************************
 * 饹: ˥塼
 **********************************************************/
Class my_page extends page {

    /***********************************************************
     * ɽʥС饤ɡ
     **********************************************************/
    function display_style() {
        global $topdir;

        /* 륷ȤΥѥ */
        $style_path = $topdir . STYLE_CSS;

        print <<<EOD

<link rel="stylesheet" type="text/css" href="$style_path">
</head>
<body topmargin="0" leftmargin="0">
EOD;
    }
    /**********************************************************
     * ȥܥɽ
     **********************************************************/
    function display_logout() {
    }
    /**********************************************************
     * ѥ󤯤ɽ
     **********************************************************/
    function display_topic() {
    }
    /**********************************************************
     * åɽ
     **********************************************************/
    function display_message() {
    }
    /**********************************************************
     * ɽ
     **********************************************************/
    function display_tab() {
    } 
    /***********************************************************
     * ܥǥɽʥС饤ɡ
     **********************************************************/
    function display_body() {
        global $sesskey;

        print <<<EOD

  <div><b>ѤǤ륿</b></div>
  <table class="table">
    <tbody>
      <tr>
        <td class="search_group">̾</td>
        <td class="search_conv"></td>
      </tr>
      <tr>
        <td class="value">&lt;@@TOADDR@@&gt;</td>
        <td class="value">ɥ쥹</td>
      </tr>
      <tr>
        <td class="value">&lt;@@SUBJECT@@&gt;</td>
        <td class="value">᡼η̾</td>
      </tr>
      <tr>
        <td class="value">&lt;@@PASSWORD@@&gt;</td>
        <td class="value">ưѥ</td>
      </tr>
      <tr>
        <td class="value">&lt;@@RCPTLIST@@&gt;</td>
        <td class="value">ưѥɤǰŹ沽᡼μ</td>
      </tr>
      <tr>
        <td class="value">&lt;@@FILENAME@@&gt;</td>
        <td class="value">źեե̾</td>
      </tr>
      <tr>
        <td class="value">&lt;@@DATE@@&gt;</td>
        <td class="value">᡼</td>
      </tr>
    </tbody>
  </table>
<br>
  <input type="button" name="close" class="close_btn" onClick="window.close();">
EOD;
    }
    /***********************************************************
     * եåɽʥС饤ɡ
     **********************************************************/
    function display_footer() {
        print <<<EOD
</body>
</html>
EOD;
    }
}

/***********************************************************
 * 
 **********************************************************/

/* 󥹥󥹺 */
$pg = new my_page();

$ret = init();
if ($ret === FALSE) {
    $sys_err = TRUE;
    $pg->display(NULL);
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/

$pg->display(CONTENT);
?>

==> sammaadmin-2.00.tar.gz: htdocs/admin/postldapadmin/samma/tmpl/help.php <==
<?php

/*
 * postLDAPadmin
 *
 * Copyright (C) 2006,2007 DesigNET, INC.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

/***********************************************************
 * إײ
 *
 * $RCSfile: help.php,v $
 * $Revision: 1.3 $
 * $Date: 2013/08/30 06:20:59 $
 **********************************************************/

include_once("../../initial");
include_once("lib/dglibpostldapadmin");
include_once("lib/dglibcommon");
include_once("lib/dglibpage");
include_once("lib/dglibsess");
include_once("lib/dglibldap");
include_once("lib/dglibsamma");

/********************************************************
ƥڡ
*********************************************************/

define("OPERATION",  "إײ");
define("TMPLFILE", "samma/samma_admin_tmpl_help.tmpl");


/***********************************************************
 * 
 **********************************************************/
$tag = array();

$ret = init();
if ($ret === FALSE) {
    syserr_display();
    exit (1);
}

/***********************************************************
 * ɽ
 **********************************************************/
/* ̤Υ */
set_tag_common($tag);

/* ڡν */
$ret = display(TMPLFILE, $tag, array(), "", "");
if ($ret === FALSE) {
    result_log($log_msg, LOG_ERR);
    syserr_display();
    exit(1);
}

?>
